@@ -15,6 +15,10 @@
 #define BUILD_GLES2
 #endif
 
+#ifndef BUILD_GLES3
+/* #undef BUILD_GLES3 */
+#endif
+
 // Miscellaneous flags
 
 #ifndef COLOR_16_BIT
@@ -80,11 +84,11 @@
 #endif
 
 #ifndef USE_LIBAVRESAMPLE
-#define USE_LIBAVRESAMPLE
+/* #undef USE_LIBAVRESAMPLE */
 #endif
 
 #ifndef USE_LIBSWRESAMPLE
-#define USE_LIBSWRESAMPLE
+/* #undef USE_LIBSWRESAMPLE */
 #endif
 
 #ifndef USE_LIBZIP
@@ -96,7 +100,7 @@
 #endif
 
 #ifndef USE_MINIZIP
-#define USE_MINIZIP
+/* #undef USE_MINIZIP */
 #endif
 
 #ifndef USE_PNG
